==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>完了</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>軸拘束の設定...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>二つのオブジェクト間に軸拘束を設定します。</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>自己診断...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>アプリケーションが正常に動作するかどうかを確認する自己診断を実行します。</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>ドローイング [&amp;a]</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>スケッチ [&amp;s]</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>レイトレーシング (&amp;R)</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>ドラフト (&amp;D)</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>スケッチベース</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>プリミティブ</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>パラメトリック</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>オブジェクトの外観</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>ポリラインツール</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>コンプリート</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>軸拘束の設定...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>二つのオブジェクト間に軸拘束を設定します。</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>自己診断...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>アプリケーションが正常に動作するかどうかを確認する自己診断を実行します。</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>ドローイング (&amp;a)</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>スケッチ (&amp;k)</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>レイトレーシング (&amp;R)</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>2次元製図 (&amp;D)</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>スケッチベース</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>プリミティブ</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">パラメトリック</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>オブジェクトの外観</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>ポリラインツール</translation>
    </message>
  </context>
</TS>
